"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.parseISODate = exports.now = exports.isWeekend = exports.isLeapYear = exports.isFutureYear = exports.isDateInRange = exports.isDateInFuture = exports.getLastDayOfMonth = exports.getISO8601Now = exports.getFormattedDate = exports.getFirstDayOfMonth = exports.getDateDiffInDays = exports.getCurrentDate = exports.formatDate = exports.calculateAge = exports.areDatesEqual = exports.addDays = void 0;
var type_utilities_1 = require("./type-utilities");
function now() {
    return Date.now();
}
exports.now = now;
function getISO8601Now() {
    var now = new Date();
    var year = now.getFullYear();
    var month = now.getMonth() + 1 < 10 ? "0".concat(now.getMonth() + 1) : now.getMonth() + 1;
    var day = now.getDate() < 10 ? "0".concat(now.getDate()) : now.getDate();
    var hour = now.getHours() < 10 ? "0".concat(now.getHours()) : now.getHours();
    var minute = now.getMinutes() < 10 ? "0".concat(now.getMinutes()) : now.getMinutes();
    var second = now.getSeconds() < 10 ? "0".concat(now.getSeconds()) : now.getSeconds();
    var millisecond = now.getMilliseconds();
    return "".concat(year, "-").concat(month, "-").concat(day, "T").concat(hour, ":").concat(minute, ":").concat(second, ".").concat(millisecond, "Z");
}
exports.getISO8601Now = getISO8601Now;
function getFormattedDate(date, separator) {
    if (separator === void 0) { separator = "."; }
    if (!date) {
        throw new Error("'date' is null or undefined.");
    }
    var d;
    if (typeof date === "string" || date instanceof String)
        d = new Date(date);
    else if ((0, type_utilities_1.isDate)(date)) {
        d = date;
    }
    else {
        throw new Error("'date' is invalid.");
    }
    separator = separator || ".";
    var isoDateTime = new Date(d.getTime() - d.getTimezoneOffset() * 60000).toISOString();
    var result = isoDateTime
        .substring(0, 10)
        .split("-")
        .reverse()
        .join(separator);
    return result;
}
exports.getFormattedDate = getFormattedDate;
/**
 * Formats a date to a string using the specified format.
 * @param date - The date object to format.
 * @param format - The format string (e.g., 'yyyy-MM-dd HH:mm:ss').
 * @returns The locals string or string[].
 */
function formatDate(date, locals) {
    var options = {
        day: "numeric",
        hour: "numeric",
        hour12: false,
        minute: "numeric",
        month: "short",
        second: "numeric",
        year: "numeric",
    };
    return new Intl.DateTimeFormat(locals, options).format(date);
}
exports.formatDate = formatDate;
/**
 * Gets the current date and time.
 * @returns The current date object.
 */
function getCurrentDate() {
    return new Date();
}
exports.getCurrentDate = getCurrentDate;
/**
 * Calculates the difference in days between two dates.
 * @param date1 - The first date.
 * @param date2 - The second date.
 * @returns The difference in days.
 */
function getDateDiffInDays(date1, date2) {
    var millisecondsPerDay = 24 * 60 * 60 * 1000;
    var timeDiff = Math.abs(date2.getTime() - date1.getTime());
    return Math.floor(timeDiff / millisecondsPerDay);
}
exports.getDateDiffInDays = getDateDiffInDays;
/**
 * Adds or subtracts a specified number of days to/from a date.
 * @param date - The date to modify.
 * @param days - The number of days to add or subtract (negative for subtraction).
 * @returns The modified date object.
 */
function addDays(date, days) {
    var newDate = new Date(date);
    newDate.setDate(date.getDate() + days);
    return newDate;
}
exports.addDays = addDays;
/**
 * Checks if a year is a leap year.
 * @param year - The year to check.
 * @returns `true` if the year is a leap year, otherwise `false`.
 */
function isLeapYear(year) {
    return (year % 4 === 0 && year % 100 !== 0) || year % 400 === 0;
}
exports.isLeapYear = isLeapYear;
/**
 * Gets the first day of a specified month.
 * @param year - The year of the month.
 * @param month - The month (0-based index).
 * @returns The first day of the month.
 */
function getFirstDayOfMonth(year, month) {
    return new Date(year, month, 1);
}
exports.getFirstDayOfMonth = getFirstDayOfMonth;
/**
 * Checks if two dates are equal.
 * @param date1 - The first date.
 * @param date2 - The second date.
 * @returns `true` if the dates are equal, otherwise `false`.
 */
function areDatesEqual(date1, date2) {
    return date1.getTime() === date2.getTime();
}
exports.areDatesEqual = areDatesEqual;
/**
 * Gets the last day of a specified month.
 * @param year - The year of the month.
 * @param month - The month (0-based index).
 * @returns The last day of the month.
 */
function getLastDayOfMonth(year, month) {
    return new Date(year, month + 1, 0);
}
exports.getLastDayOfMonth = getLastDayOfMonth;
/**
 * Checks if a date is in the future.
 * @param date - The date to check.
 * @returns `true` if the date is in the future, otherwise `false`.
 */
function isDateInFuture(date) {
    var today = new Date();
    return date > today;
}
exports.isDateInFuture = isDateInFuture;
/**
 * Checks if a date is within a specified range.
 * @param date - The date to check.
 * @param startDate - The start date of the range.
 * @param endDate - The end date of the range.
 * @returns `true` if the date is within the range, otherwise `false`.
 */
function isDateInRange(date, startDate, endDate) {
    return date >= startDate && date <= endDate;
}
exports.isDateInRange = isDateInRange;
/**
 * Calculates the age based on the provided birth date.
 * @param birthDate - The birth date.
 * @returns The age in years.
 */
function calculateAge(birthDate) {
    var today = new Date();
    var age = today.getFullYear() - birthDate.getFullYear();
    var monthDiff = today.getMonth() - birthDate.getMonth();
    if (monthDiff < 0 ||
        (monthDiff === 0 && today.getDate() < birthDate.getDate())) {
        age--;
    }
    return age;
}
exports.calculateAge = calculateAge;
/**
 * Checks if a given year is a future year.
 * @param year - The year to check.
 * @returns `true` if the year is in the future, otherwise `false`.
 */
function isFutureYear(year) {
    var currentYear = new Date().getFullYear();
    return year > currentYear;
}
exports.isFutureYear = isFutureYear;
/**
 * Checks if a date is a weekend day (Saturday or Sunday).
 * @param date - The date to check.
 * @returns `true` if the date is a weekend day, otherwise `false`.
 */
function isWeekend(date) {
    var day = date.getDay();
    return day === 0 || day === 6;
}
exports.isWeekend = isWeekend;
/**
 * Converts a date string in ISO 8601 format to a Date object.
 * @param dateString - The date string in ISO 8601 format.
 * @returns The parsed Date object, or `null` if the date string is invalid.
 */
function parseISODate(dateString) {
    var date = new Date(dateString);
    return isNaN(date.getTime()) ? null : date;
}
exports.parseISODate = parseISODate;
//# sourceMappingURL=date-utilities.js.map