import { UnaryFunction } from "../types";
/**
 * Creates a function that accepts up to `n` arguments, ignoring unknown additional arguments.
 */
declare function ary(func: (...args: unknown[]) => unknown, n: number): (...args: unknown[]) => unknown;
/**
 * Creates a function that invokes `func` only before the specified `n` calls.
 */
declare function before<T extends Function>(n: number, func: T): T;
/**
 * Creates a function that invokes `func` with the `this` binding of `thisArg` and prepends unknown additional supplied arguments.
 */
declare function bind(func: Function, thisArg: unknown, ...partials: unknown[]): Function;
/**
 * Creates a function that invokes the method at `object[key]` with the `this` binding of `object` and prepends unknown additional supplied arguments.
 */
declare function bindKey<T, K extends keyof T>(object: T, key: K, ...partials: unknown[]): (...args: unknown[]) => unknown;
/**
 * Creates a curried function that invokes `func` with arguments provided one at a time.
 */
declare function curry<T extends (...args: unknown[]) => unknown>(func: T, arity?: number): T;
/**
 * Creates a curried function that invokes `func` with arguments provided in reverse order.
 */
declare function curryRight<T extends (...args: unknown[]) => unknown>(func: T, arity?: number): T;
/**
 * Creates a debounced function that delays invoking `func` until after `wait` milliseconds have elapsed since the last time the debounced function was invoked.
 */
declare function debounce(func: Function, wait?: number): Function;
/**
 * Defers invoking the `func` until the current call stack has cleared.
 */
declare function defer(func: Function): void;
/**
 * Invokes `func` after `wait` milliseconds.
 */
declare function delay(func: Function, wait?: number, ...args: unknown[]): void;
/**
 * Creates a function that invokes `func` with arguments reversed.
 */
declare function flip(func: Function): Function;
/**
 * Creates a memoized function that caches the result of `func` for the given argument.
 */
declare function memoize(func: Function): Function;
/**
 * Creates a negated version of `predicate` function.
 */
declare function negate(predicate: Function): Function;
/**
 * Creates a function that invokes `func` only once. Subsequent calls to the returned function will return the result of the first call.
 */
declare function once(func: Function): Function;
/**
 * Creates a function that invokes `func` with arguments transformed by corresponding `transforms`.
 */
declare function overArgs(func: Function, transforms: Function[]): Function;
/**
 * Creates a partially applied function by filling in `partials` argument placeholders.
 */
declare function partial(func: Function, ...partials: unknown[]): Function;
/**
 * Creates a partially applied function by filling in `partials` argument placeholders from the right.
 */
declare function partialRight(func: Function, ...partials: unknown[]): Function;
/**
 * Creates a function that invokes `func` with arguments rearranged according to the specified `indexes`.
 */
declare function rearg(func: Function, indexes: number[]): Function;
/**
 * Creates a function that invokes `func` with the rest arguments it receives.
 */
declare function rest(func: Function, start?: number): Function;
/**
 * Creates a function that invokes `func` with an array of arguments, spreading them out.
 */
declare function spread(func: Function): Function;
/**
 * Creates a throttled function that invokes `func` at most once per every `wait` milliseconds.
 */
declare function throttle(func: Function, wait?: number): Function;
/**
 * Creates a function that accepts only one argument, discarding unknown additional arguments.
 */
declare function unary(func: Function): Function;
/**
 * Wraps `func` to enable currying.
 */
declare function wrap(func: (...args: unknown[]) => unknown, wrapper: (...args: unknown[]) => unknown): (...args: unknown[]) => unknown;
/**
 * Invokes `func` when it is called `n` or more times.
 */
declare function after(n: number, func: Function): Function;
/**
 * Creates a pipeline of synchronous unary functions and returns a new function.
 * When the returned function is called with an argument, it passes that argument
 * through each function in the pipeline, starting with the first function, and
 * returns the final result.
 *
 * @param first The first function to apply in the pipeline.
 * @param fns The rest of the functions to apply in the pipeline.
 * @returns A new function that applies the pipeline to its argument.
 */
declare function pipe<T>(first: UnaryFunction<T, T>, ...fns: Array<UnaryFunction<T, T>>): (initial: T) => T;
/**
 * Similar to the `pipe` function, but designed for asynchronous unary functions.
 * It creates a pipeline of asynchronous functions and returns a new function.
 * When the returned function is called with an argument, it asynchronously
 * passes that argument through each function in the pipeline, awaiting each
 * function before applying the next one, and returns a Promise of the final result.
 *
 * @param first The first async function to apply in the pipeline.
 * @param fns The rest of the async functions to apply in the pipeline.
 * @returns A new function that applies the pipeline to its argument.
 */
declare function pipeAsync<T>(first: UnaryFunction<T, Promise<T>>, ...fns: Array<UnaryFunction<T, Promise<T>>>): (initial: T) => Promise<T>;
/**
 * Composes multiple functions into a single function that applies them in right-to-left order.
 *
 * @template T - The type of the input and output values.
 * @param {...((input: T) => T)[]} fns - The functions to compose.
 * @returns {(input: T) => T} A function that applies the composed functions to the input value.
 */
declare function compose<T>(...fns: ((input: T) => T)[]): (input: T) => T;
export { after, ary, before, bind, bindKey, compose, curry, curryRight, debounce, defer, delay, flip, memoize, negate, once, overArgs, partial, partialRight, pipe, pipeAsync, rearg, rest, spread, throttle, unary, wrap, };
//# sourceMappingURL=function-utilities.d.ts.map