/**
 * Converts a string to camel case.
 */
function camelCase(str) {
    var _a;
    var words = str.match(/[A-Za-z0-9]+/g) || [];
    if (words.length === 0) {
        return "";
    }
    var firstWord = (_a = words[0]) === null || _a === void 0 ? void 0 : _a.toLowerCase();
    var restWords = words
        .slice(1)
        .map(function (word) {
        return word.charAt(0).toUpperCase() + word.slice(1).toLowerCase();
    });
    return firstWord + restWords.join("");
}
/**
 * Capitalizes the first character of a string.
 */
function capitalize(str) {
    return str.charAt(0).toUpperCase() + str.slice(1);
}
/**
 * Removes diacritical marks from a string.
 */
function deburr(str) {
    return str.normalize("NFD").replace(/[\u0300-\u036f]/g, "");
}
/**
 * Checks if a string ends with the given target string.
 */
function endsWith(str, target, position) {
    if (position === undefined || position > str.length) {
        position = str.length;
    }
    var end = position - target.length;
    return str.slice(end, position) === target;
}
/**
 * Escapes special characters in a string.
 */
function escape(str) {
    return str.replace(/[<>&"']/g, function (match) {
        switch (match) {
            case "<":
                return "&lt;";
            case ">":
                return "&gt;";
            case "&":
                return "&amp;";
            case '"':
                return "&quot;";
            case "'":
                return "&#39;";
            default:
                return match;
        }
    });
}
/**
 * Escapes special characters in a regular expression string.
 */
function escapeRegExp(str) {
    return str.replace(/[.*+?^${}()|[\]\\]/g, "\\$&");
}
/**
 * Converts a string to kebab case.
 */
function kebabCase(str) {
    return str
        .replace(/([a-z])([A-Z])/g, "$1-$2")
        .replace(/[_\s]+/g, "-")
        .toLowerCase();
}
/**
 * Converts a string to lower case.
 */
function lowerCase(str) {
    return str.toLowerCase();
}
/**
 * Converts the first character of a string to lower case.
 */
function lowerFirst(str) {
    return str.charAt(0).toLowerCase() + str.slice(1);
}
/**
 * Pads a string on both sides with characters until it reaches the given length.
 */
function pad(str, length, chars) {
    if (chars === void 0) { chars = " "; }
    var strLength = str.length;
    if (strLength >= length) {
        return str;
    }
    var padLength = length - strLength;
    var leftPadding = chars
        .repeat(Math.ceil(padLength / chars.length))
        .slice(0, padLength);
    var rightPadding = chars
        .repeat(Math.ceil(padLength / chars.length))
        .slice(0, padLength - leftPadding.length);
    return leftPadding + str + rightPadding;
}
/**
 * Pads a string on the end with characters until it reaches the given length.
 */
function padEnd(str, length, chars) {
    if (chars === void 0) { chars = " "; }
    var strLength = str.length;
    if (strLength >= length) {
        return str;
    }
    var padLength = length - strLength;
    var padding = chars
        .repeat(Math.ceil(padLength / chars.length))
        .slice(0, padLength);
    return str + padding;
}
/**
 * Pads a string on the start with characters until it reaches the given length.
 */
function padStart(str, length, chars) {
    if (chars === void 0) { chars = " "; }
    var strLength = str.length;
    if (strLength >= length) {
        return str;
    }
    var padLength = length - strLength;
    var padding = chars
        .repeat(Math.ceil(padLength / chars.length))
        .slice(0, padLength);
    return padding + str;
}
/**
 * Parses a string to an integer of the specified radix.
 */
function parseInt(str, radix) {
    if (radix === void 0) { radix = 10; }
    return Number.parseInt(str, radix);
}
/**
 * Repeats a string `n` times.
 */
function repeat(str, n) {
    return str.repeat(n);
}
/**
 * Replaces all occurrences of a pattern in a string with a replacement.
 */
function replace(str, pattern, replacement) {
    return str.replace(pattern, replacement);
}
/**
 * Converts a string to snake case.
 */
function snakeCase(str) {
    return str
        .replace(/([a-z])([A-Z])/g, "$1_$2")
        .replace(/[_\s]+/g, "_")
        .toLowerCase();
}
/**
 * Splits a string into an array of words.
 */
function split(str, separator, limit) {
    return str.split(separator, limit);
}
/**
 * Converts a string to start case (capitalizes the first character of each word).
 */
function startCase(str) {
    return str
        .replace(/([a-z])([A-Z])/g, "$1 $2")
        .replace(/[_\s]+/g, " ")
        .replace(/\b\w/g, function (char) { return char.toUpperCase(); });
}
/**
 * Checks if a string starts with the given target string.
 */
function startsWith(str, target, position) {
    if (position === void 0) { position = 0; }
    return str.slice(position, position + target.length) === target;
}
/**
 * Evaluates a template string with interpolated placeholders.
 */
function template(str, placeholders) {
    return str.replace(/{{(.*?)}}/g, function (_, key) {
        return String(placeholders[key.trim()]);
    });
}
/**
 * Converts a string to lower case.
 */
function toLower(str) {
    return str.toLowerCase();
}
/**
 * Converts a string to upper case.
 */
function toUpper(str) {
    return str.toUpperCase();
}
/**
 * Removes leading and trailing whitespace from a string.
 */
function trim(str) {
    return str.trim();
}
/**
 * Removes trailing whitespace from a string.
 */
function trimEnd(str) {
    return str.trimEnd();
}
/**
 * Removes leading whitespace from a string.
 */
function trimStart(str) {
    return str.trimStart();
}
/**
 * Truncates a string to a specified length.
 */
function truncate(str, options) {
    if (options === void 0) { options = { length: 30, omission: "..." }; }
    var length = options.length, _a = options.omission, omission = _a === void 0 ? "..." : _a, separator = options.separator;
    if (str.length <= length) {
        return str;
    }
    var truncated = str.slice(0, length);
    if (separator) {
        var separatorMatch = truncated.match(new RegExp(separator + "$"));
        if (separatorMatch) {
            truncated = truncated.slice(0, separatorMatch.index);
        }
    }
    return truncated + omission;
}
/**
 * Unescapes special characters in an HTML string.
 */
function unescape(str) {
    return str.replace(/&amp;|&lt;|&gt;|&quot;|&#39;/g, function (match) {
        switch (match) {
            case "&amp;":
                return "&";
            case "&lt;":
                return "<";
            case "&gt;":
                return ">";
            case "&quot;":
                return '"';
            case "&#39;":
                return "'";
            default:
                return match;
        }
    });
}
/**
 * Converts a string to upper case.
 */
function upperCase(str) {
    return str.toUpperCase();
}
/**
 * Converts the first character of a string to upper case.
 */
function upperFirst(str) {
    return str.charAt(0).toUpperCase() + str.slice(1);
}
/**
 * Splits a string into an array of words.
 */
function words(str, pattern) {
    return str.match(pattern || /\b\w+\b/g) || [];
}
/**
 * A function to convert ArrayBuffer to hexadecimal
 */
function toHexAsBuffer(buffer) {
    var hexCodes = [];
    var view = new DataView(buffer);
    for (var i = 0; i < view.byteLength; i += 4) {
        var value = view.getUint32(i);
        var stringValue = value.toString(16);
        var padding = "00000000";
        var paddedValue = (padding + stringValue).slice(-padding.length);
        hexCodes.push(paddedValue);
    }
    return hexCodes.join("");
}
/**
 * A function to convert string to hexadecimal
 */
function toHex(s) {
    var hex = "";
    for (var i = 0; i < s.length; i++) {
        hex += "" + s.charCodeAt(i).toString(16);
    }
    return hex;
}
/**
 * UUIDv1 generation
 */
function generateUUIDv1() {
    var now = typeof performance !== "undefined" && performance.now != null
        ? performance.now()
        : Date.now();
    var uuid = "xxxxxxxx-xxxx-4xxx-yxxx-xxxxxxxxxxxx".replace(/[xy]/g, function (c) {
        var r = (now + Math.random() * 16) % 16 | 0;
        return (c === "x" ? r : (r & 0x3) | 0x8).toString(16);
    });
    return uuid;
}
/**
 * UUIDv4 generation
 */
function generateUUIDv4() {
    var d = new Date().getTime();
    return "xxxxxxxx-xxxx-4xxx-yxxx-xxxxxxxxxxxx".replace(/[xy]/g, function (c) {
        var r = (d + Math.random() * 16) % 16 | 0;
        d = Math.floor(d / 16);
        return (c === "x" ? r : (r & 0x3) | 0x8).toString(16);
    });
}
/**
 * This function takes a string as input and returns an encoded Uint8Array.
 * It uses the TextEncoder object which is a global object in modern browsers.
 * It provides encoding of string data to bytes using UTF-8 encoding.
 *
 * @param message - The string that should be encoded.
 * @returns The encoded Uint8Array.
 */
function encode(message) {
    var encoder = new TextEncoder();
    return encoder.encode(message);
}
/**
 * This function takes a Uint8Array as input and returns a decoded string.
 * It uses the TextDecoder object which is a global object in modern browsers.
 * It provides decoding of text data that has been encoded to bytes.
 *
 * @param data - The Uint8Array that should be decoded.
 * @returns The decoded string.
 */
function decode(data) {
    var decoder = new TextDecoder();
    return decoder.decode(data);
}
function isNullOrWhiteSpace(str) {
    return str === null || str == "" || str.match(/^ *$/) !== null;
}
function isNullOrEmpty(str) {
    return str === null || str == "";
}
function isNotNullOrWhiteSpace(str) {
    return !isNullOrWhiteSpace(str);
}
function isNotNullOrEmpty(str) {
    return !isNullOrEmpty(str);
}
export { camelCase, capitalize, deburr, decode, encode, endsWith, escape, escapeRegExp, generateUUIDv1, generateUUIDv4, isNotNullOrEmpty, isNotNullOrWhiteSpace, isNullOrEmpty, isNullOrWhiteSpace, kebabCase, lowerCase, lowerFirst, pad, padEnd, padStart, parseInt, repeat, replace, snakeCase, split, startCase, startsWith, template, toHex, toHexAsBuffer, toLower, toUpper, trim, trimEnd, trimStart, truncate, unescape, upperCase, upperFirst, words, };
//# sourceMappingURL=string-utilities.js.map